@@ -7,15 +7,13 @@ from pathlib import Path
 
 from enchant import request_pwl_dict
 from enchant.utils import levenshtein
+from transformers import AutoModelForTokenClassification, AutoTokenizer, pipeline
 
 from ..region import DataError, TextConfig
 from ..span import Span
 from ..util import load_config
 from ..vision import Vision
 
-#from transformers import AutoModelForTokenClassification, AutoTokenizer, pipeline
-from transformers import pipeline
-
 # b ../docint/pipeline/sents_fixer.py:87
 
 
@@ -55,7 +53,6 @@ class WordsFixer:
         officer_at_start,
     ):
 
-
         ignore_puncts = string.punctuation
         self.punct_tbl = str.maketrans(ignore_puncts, " " * len(ignore_puncts))
         self.item_name = item_name
@@ -86,18 +83,14 @@ class WordsFixer:
         u_lines = [line.split() for line in Path(self.unicode_file).read_text().split("\n") if line.strip()]
         self.unicode_dict = dict((u, a if a != "<ignore>" else "") for u, a in u_lines)
 
-        self.dictionary = request_pwl_dict(str(self.dict_file))
-
         # TODO PLEASE MOVE THIS TO OPTIONS
-        print('Reading model')
-        
-        #tokenizer = AutoTokenizer.from_pretrained("/Users/mukund/Github/huggingface/bert-base-NER")
-        #model = AutoModelForTokenClassification.from_pretrained("/Users/mukund/Github/huggingface/bert-base-NER")
+        tokenizer = AutoTokenizer.from_pretrained("/Users/mukund/Github/huggingface/bert-base-NER")
+        model = AutoModelForTokenClassification.from_pretrained("/Users/mukund/Github/huggingface/bert-base-NER")
 
+        self.nlp = pipeline("ner", model=model, tokenizer=tokenizer)
+        # self.nlp = pipeline("ner")
 
-        #self.nlp = pipeline("ner", model=model, tokenizer=tokenizer)
-        self.nlp = pipeline("ner")
-        print('DONE Reading model')                
+        self.dictionary = request_pwl_dict(str(self.dict_file))
 
         self.test_doc = True
 
