@@ -22,6 +22,8 @@ class FactoryMeta:
     default_config: Optional[Dict[str, Any]] = None  # noqa: E704
     assigns: Iterable[str] = tuple()
     requires: Iterable[str] = tuple()
+    packages: Iterable[str] = tuple()
+    os_packages: Iterable[str] = tuple()
 
 
 class Vision:
@@ -44,13 +46,12 @@ class Vision:
 
         viz.ignore_docs = config.get("ignore_docs", [])
         for pipe_config in config.get("pipeline", []):
-            print(f'Adding {pipe_config.get("name")}')            
+            print(f'Adding {pipe_config.get("name")}')
             viz.add_pipe(
                 pipe_config.get("name"),
                 pipe_config=pipe_config.get("config", {}),
             )
-            print(f'Added {pipe_config.get("name")}')
-        print(f'Done creating pipeline')
+        print('Done creating pipeline')
 
         return viz
 
@@ -261,6 +262,8 @@ class Vision:
         default_config: Dict[str, Any] = SimpleFrozenDict(),
         assigns: Iterable[str] = SimpleFrozenList(),
         requires: Iterable[str] = SimpleFrozenList(),
+        packages: Iterable[str] = SimpleFrozenList(),
+        os_packages: Iterable[str] = SimpleFrozenList(),
         func: Optional[Callable] = None,
     ) -> Callable:
         if not isinstance(name, str):
@@ -276,6 +279,8 @@ class Vision:
                 default_config=default_config,
                 assigns=assigns,
                 requires=requires,
+                packages=packages,
+                os_packages=packages,
             )
 
             cls.factories_meta[name] = factory_meta
